package main

import (
	"dwelling-upload/internal/configuration"
	"dwelling-upload/pkg/logging"
	"dwelling-upload/pkg/utils"
	"flag"
	"fmt"
	"io/ioutil"
	"log"
	"os"
	"path"
	"time"
)

var configPath *string = flag.String("conf", "config.yaml", "path to configuration file")
var showVersion *bool = flag.Bool("v", false, "show version")

var version string

func main() {
	flag.Parse()

	if *showVersion {
		fmt.Println("dwelling-upload-clean Ver. ", version, "\nCopyright (c) 2022,2023 Alexander \"Arav\" Andreev <me@arav.su>")
		return
	}

	config, err := configuration.LoadConfiguration(*configPath)
	if err != nil {
		log.Fatalln(err)
	}

	logErr, err := logging.New(config.Log.CleanError)
	if err != nil {
		log.Fatalln("failed to open error logger:", err)
	}
	defer logErr.Close()

	logClean, err := logging.New(config.Log.Clean)
	if err != nil {
		log.Fatalln("failed to open error logger:", err)
	}
	defer logClean.Close()

	uploadsDir, err := ioutil.ReadDir(config.Uploads.Directory)
	if err != nil {
		logErr.Fatalf("failed to open directory %s: %s\n", config.Uploads.Directory, err)
	}

	var deletedCount int64 = 0
	var deletedSize int64 = 0

	for _, entry := range uploadsDir {
		if time.Now().UTC().Sub(entry.ModTime().UTC()) >= time.Duration(config.Uploads.Limits.KeepForHours)*time.Hour {
			if err := os.Remove(path.Join(config.Uploads.Directory, entry.Name())); err != nil {
				logErr.Println("failed to remove file ", entry.Name(), ": ", err)
			} else {
				deletedSize += entry.Size()
				deletedCount++
			}
		}
	}

	_, _, cFSz := utils.ConvertFileSize(deletedSize)

	if deletedCount > 0 {
		logClean.Printf("%d %s", deletedCount, cFSz)
	}
}
